.. _coordinate_operation:

Coordinate Operations
=====================

CoordinateOperation
--------------------
.. autoclass:: pyproj.crs.CoordinateOperation
    :members:
    :inherited-members:


Param
------

.. autoclass:: pyproj._crs.Param
    :members:

Grid
----

.. autoclass:: pyproj._crs.Grid
    :members:


AlbersEqualAreaConversion
---------------------------

.. autoclass:: pyproj.crs.coordinate_operation.AlbersEqualAreaConversion
    :members:
    :show-inheritance:
    :special-members: __new__


AzumuthalEquidistantConversion
-------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.AzumuthalEquidistantConversion
    :members:
    :show-inheritance:
    :special-members: __new__


EquidistantCylindricalConversion
--------------------------------
.. autoclass:: pyproj.crs.coordinate_operation.EquidistantCylindricalConversion
    :members:
    :show-inheritance:
    :special-members: __new__


GeostationarySatelliteConversion
--------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.GeostationarySatelliteConversion
    :members:
    :show-inheritance:
    :special-members: __new__


LambertAzumuthalEqualAreaConversion
-----------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.LambertAzumuthalEqualAreaConversion
    :members:
    :show-inheritance:
    :special-members: __new__


LambertConformalConic1SPConversion
-----------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.LambertConformalConic1SPConversion
    :members:
    :show-inheritance:
    :special-members: __new__


LambertConformalConic2SPConversion
-----------------------------------
.. autoclass:: pyproj.crs.coordinate_operation.LambertConformalConic2SPConversion
    :members:
    :show-inheritance:
    :special-members: __new__


LambertCylindricalEqualAreaConversion
-------------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.LambertCylindricalEqualAreaConversion
    :members:
    :show-inheritance:
    :special-members: __new__

.. autoclass:: pyproj.crs.coordinate_operation.LambertCylindricalEqualAreaScaleConversion

    :members:
    :show-inheritance:
    :special-members: __new__


MercatorAConversion
--------------------
.. autoclass:: pyproj.crs.coordinate_operation.MercatorAConversion
    :members:
    :show-inheritance:
    :special-members: __new__


MercatorBConversion
-------------------

.. autoclass:: pyproj.crs.coordinate_operation.MercatorBConversion
    :members:
    :show-inheritance:
    :special-members: __new__


HotineObliqueMercatorBConversion
---------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.HotineObliqueMercatorBConversion
    :members:
    :show-inheritance:
    :special-members: __new__


OrthographicConversion
-----------------------

.. autoclass:: pyproj.crs.coordinate_operation.OrthographicConversion
    :members:
    :show-inheritance:
    :special-members: __new__


PlateCarreeConversion
--------------------------------
.. autoclass:: pyproj.crs.coordinate_operation.PlateCarreeConversion
    :members:
    :show-inheritance:
    :special-members: __new__


PolarStereographicAConversion
-----------------------------

.. autoclass:: pyproj.crs.coordinate_operation.PolarStereographicAConversion
    :members:
    :show-inheritance:
    :special-members: __new__


PolarStereographicBConversion
-----------------------------

.. autoclass:: pyproj.crs.coordinate_operation.PolarStereographicBConversion
    :members:
    :show-inheritance:
    :special-members: __new__


SinusoidalConversion
---------------------

.. autoclass:: pyproj.crs.coordinate_operation.SinusoidalConversion
    :members:
    :show-inheritance:
    :special-members: __new__


StereographicConversion
------------------------

.. autoclass:: pyproj.crs.coordinate_operation.StereographicConversion
    :members:
    :show-inheritance:
    :special-members: __new__


UTMConversion
-------------

.. autoclass:: pyproj.crs.coordinate_operation.UTMConversion
    :members:
    :show-inheritance:
    :special-members: __new__


TransverseMercatorConversion
----------------------------

.. autoclass:: pyproj.crs.coordinate_operation.TransverseMercatorConversion
    :members:
    :show-inheritance:
    :special-members: __new__


VerticalPerspectiveConversion
-----------------------------

.. autoclass:: pyproj.crs.coordinate_operation.VerticalPerspectiveConversion
    :members:
    :show-inheritance:
    :special-members: __new__


RotatedLatitudeLongitudeConversion
----------------------------------

.. autoclass:: pyproj.crs.coordinate_operation.RotatedLatitudeLongitudeConversion
    :members:
    :show-inheritance:
    :special-members: __new__


ToWGS84Transformation
---------------------

.. autoclass:: pyproj.crs.coordinate_operation.ToWGS84Transformation
    :members:
    :show-inheritance:
    :special-members: __new__
